diff mbox series

[v1,1/1] input: tps65215: Add support for TI TPS65215 PMIC

Message ID 20241226220049.398794-2-s-ramamoorthy@ti.com
State New
Headers show
Series Add TI TPS65215 PMIC Input Support | expand

Commit Message

Shree Ramamoorthy Dec. 26, 2024, 10 p.m. UTC
Update descriptions to reflect this file applies to TPS65215 and
TPS65219.

Signed-off-by: Shree Ramamoorthy <s-ramamoorthy@ti.com>
---
 drivers/input/misc/tps65219-pwrbutton.c | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)
diff mbox series

Patch

diff --git a/drivers/input/misc/tps65219-pwrbutton.c b/drivers/input/misc/tps65219-pwrbutton.c
index 7a58bae4f1a0..27a8d10d81ac 100644
--- a/drivers/input/misc/tps65219-pwrbutton.c
+++ b/drivers/input/misc/tps65219-pwrbutton.c
@@ -1,6 +1,6 @@ 
 // SPDX-License-Identifier: GPL-2.0
 //
 // Driver for TPS65219 Push Button
 //
 // Copyright (C) 2022 BayLibre Incorporated - https://www.baylibre.com/
 
@@ -145,6 +145,6 @@  static struct platform_driver tps65219_pb_driver = {
 };
 module_platform_driver(tps65219_pb_driver);
 
-MODULE_DESCRIPTION("TPS65219 Power Button");
+MODULE_DESCRIPTION("TPS65215/TPS65219 Power Button");
 MODULE_LICENSE("GPL");
 MODULE_AUTHOR("Markus Schneider-Pargmann <msp@baylibre.com");
@@ -1,6 +1,6 @@ 
 // SPDX-License-Identifier: GPL-2.0
 //
-// Driver for TPS65219 Push Button
+// Driver for TPS65215/TPS65219 Push Button
 //
 // Copyright (C) 2022 BayLibre Incorporated - https://www.baylibre.com/